@@ -5,6 +5,10 @@
  *          Szabolcs Ban <shooby@gnome.hu>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -12,7 +16,6 @@
 #include <math.h>
 #include <dirent.h>
 
-#include <config.h>
 #include <gnome.h>
 #include <gtk/gtk.h>
 
@@ -30,8 +33,6 @@ GtkWidget *bah_window = NULL;
 GtkWidget *draw_area;
 static GtkWidget *app, *vb, *appbar, *pref_dialog;
 GtkWidget *next_draw_area; /* XXX Shouldn't be this much externls! */
-GdkPixmap *backpixmap = NULL;
-GdkPixmap *next_backpixmap = NULL;
 field_props field[FIELDSIZE*FIELDSIZE];
 GdkPixmap *box_pixmap = NULL;
 GdkPixmap *ball_pixmap = NULL;
@@ -140,9 +141,7 @@ start_game(void)
 	char string[20];
 
 	gnome_appbar_set_status(GNOME_APPBAR(appbar), _("Match five balls of the same color in a row to score!"));
-	draw_field(draw_area,0);
 	draw_all_balls(draw_area, -1);
-	gtk_widget_draw(draw_area, NULL);
 	draw_preview();	
 	active = -1;
 	target = -1;
@@ -180,7 +179,7 @@ draw_preview(void)
 
 	for(i = 0; i < 3; i++)
 	{
-		draw_ball(next_draw_area, next_backpixmap, i, 0, preview[i], 0, 1);
+		draw_ball(next_draw_area, i, 0);
 	}
 }
 
@@ -233,59 +232,26 @@ draw_all_balls(GtkWidget *widget, int coord)
 
 	if(coord != -1)
 	{
-		draw_ball(widget, backpixmap, coord%FIELDSIZE, coord/FIELDSIZE, field[coord].color, 0, 1);
+		draw_ball(widget, coord%FIELDSIZE, coord/FIELDSIZE);
 		return;
 	}
 
-	for(i = 0; i < FIELDSIZE*FIELDSIZE; i++)
-	{
-		if(field[i].color != 0)
-		{
-			draw_ball(widget, backpixmap, i%FIELDSIZE, i/FIELDSIZE, field[i].color, 0, 1);
-		}
-	}
+        /* Redraw the whole field */
+        gdk_window_invalidate_rect(widget->window, NULL, FALSE);
 }
 
 void
-draw_box(GtkWidget *widget, GdkPixmap *bpm, int x, int y, int redraw)
+draw_box(GtkWidget *widget, int x, int y)
 {
-	gdk_draw_drawable(bpm, widget->style->fg_gc[GTK_WIDGET_STATE (widget)], box_pixmap,
-			0, 0, x*BOXSIZE, y*BOXSIZE, BOXSIZE, BOXSIZE);
-	if(redraw)
-	{
-		GdkRectangle update_rect;
-
-		update_rect.x = x*BOXSIZE;
-		update_rect.y = y*BOXSIZE;
-		update_rect.width = BOXSIZE;
-		update_rect.height = BOXSIZE;   
-		gtk_widget_draw(widget, &update_rect);
-	}
+	gtk_widget_queue_draw_area(widget, x * BOXSIZE, y * BOXSIZE,
+				   BOXSIZE, BOXSIZE);
 }
 
 void
-draw_ball(GtkWidget *widget, GdkPixmap *bpm, int x, int y, int color, int phase, int redraw)
+draw_ball(GtkWidget *widget, int x, int y)
 {
-	GdkGC *gc;
-
-	draw_box(widget, bpm, x, y, 0);
-	phase = ABS(ABS(3-phase)-3);
-	gc = widget->style->fg_gc[GTK_STATE_NORMAL];
-	gdk_gc_set_clip_mask (gc, ball_mask);
-	gdk_gc_set_clip_origin (gc, 5 + x*BOXSIZE - phase*BALLSIZE, 5 + y*BOXSIZE - (color - 1)*BALLSIZE);
-	gdk_draw_drawable(bpm, gc, ball_pixmap,
-			phase*BALLSIZE, (color - 1)*BALLSIZE, 5 + x*BOXSIZE, 5 + y*BOXSIZE, BALLSIZE, BALLSIZE);
-	gdk_gc_set_clip_mask (gc, NULL);
-	if(redraw == 1)
-	{
-		GdkRectangle update_rect;
-
-		update_rect.x = x*BOXSIZE;
-		update_rect.y = y*BOXSIZE;
-		update_rect.width = BOXSIZE;
-		update_rect.height = BOXSIZE;   
-		gtk_widget_draw(widget, &update_rect);
-	}
+	gtk_widget_queue_draw_area(widget, x * BOXSIZE, y * BOXSIZE,
+				   BOXSIZE, BOXSIZE);
 }
 
 int
@@ -361,7 +327,7 @@ deactivate(GtkWidget *widget, int x, int y)
 {
 	field[active].active = 0;
 	field[active].phase = 0; 
-	draw_ball(widget, backpixmap, x, y, field[active].color, field[active].phase, 1);
+	draw_ball(widget, x, y);
 	active = -1;
 }
 
@@ -435,29 +401,78 @@ button_press_event (GtkWidget *widget, GdkEvent *event)
 	return TRUE;
 }
 
-void
-draw_field(GtkWidget *widget, gint redraw)
+/* Redraw the whole preview */
+static gint
+preview_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer gp)
 {
-	int i, j;
+	GdkGC *gc;
+	int i;
 
-	for(i=0; i<9; i++)
-		for(j=0; j<9; j++)
-		{
-			draw_box(widget, backpixmap, i, j, redraw);
-		}
+	for (i = 0; i < 3; i++) {
+		/* Draw the box */
+		gdk_draw_drawable(widget->window,
+				  widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
+				  box_pixmap, 0, 0,
+				  i * BOXSIZE, 0, BOXSIZE, BOXSIZE);
+
+		/* Draw the ball */
+		gc = widget->style->fg_gc[GTK_STATE_NORMAL];
+		gdk_gc_set_clip_mask (gc, ball_mask);
+		gdk_gc_set_clip_origin (gc, 5 + i * BOXSIZE,
+					5 - (preview[i] - 1) * BALLSIZE);
+		gdk_draw_drawable(widget->window, gc, ball_pixmap,
+				  0, (preview[i] - 1) * BALLSIZE,
+				  5 + i * BOXSIZE, 5, BALLSIZE, BALLSIZE);
+		gdk_gc_set_clip_mask (gc, NULL);
+	}
+
+	return FALSE;
 }
 
-/* Redraw the screen from the backing pixmap */
+/* Redraw a part of the field */
 static gint
-expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer gp)
+field_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer gp)
 {
-	GdkPixmap *bpm = (GdkPixmap *)gp;		
-	gdk_draw_drawable(widget->window,
-			widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
-			bpm,
-			event->area.x, event->area.y,
-			event->area.x, event->area.y,
-			event->area.width, event->area.height);
+	GdkGC *gc;
+	guint x_start, x_end, y_start, y_end, i, j, idx;
+
+	x_start = event->area.x / BOXSIZE;
+	x_end = x_start + event->area.width / BOXSIZE + 1;
+
+	y_start = event->area.y / BOXSIZE;
+	y_end = y_start + event->area.height / BOXSIZE + 1;
+
+	for (i = y_start; i < y_end; i++) {
+		for (j = x_start; j < x_end; j++) {
+			idx = j + i * FIELDSIZE;
+
+			/* Draw the box */
+			gdk_draw_drawable(widget->window,
+					  widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
+					  box_pixmap, 0, 0,
+					  j * BOXSIZE, i * BOXSIZE, BOXSIZE, BOXSIZE);
+
+			/* Draw the ball */
+			if (field[idx].color != 0) {
+				int phase = field[idx].phase;
+				int color = field[idx].color;
+				int x = idx % FIELDSIZE;
+				int y = idx / FIELDSIZE;
+
+				phase = ABS(ABS(3-phase)-3);
+				gc = widget->style->fg_gc[GTK_STATE_NORMAL];
+				gdk_gc_set_clip_mask (gc, ball_mask);
+				gdk_gc_set_clip_origin (gc, 5 + x * BOXSIZE - phase * BALLSIZE,
+							5 + y * BOXSIZE - (color - 1) * BALLSIZE);
+				gdk_draw_drawable(widget->window, gc, ball_pixmap,
+						  phase * BALLSIZE,
+						  (color - 1) * BALLSIZE,
+						  5 + x * BOXSIZE, 5 + y * BOXSIZE,
+						  BALLSIZE, BALLSIZE);
+				gdk_gc_set_clip_mask (gc, NULL);
+			}
+		}
+	}
 
 	return FALSE;
 }
@@ -472,9 +487,8 @@ kill_tagged(GtkWidget *widget, int num)
 			field[field[i].pathsearch].color = 0;
 			field[field[i].pathsearch].phase = 0;
 			field[field[i].pathsearch].active = 0;
-			draw_box(widget, backpixmap, field[i].pathsearch%9, field[i].pathsearch/9, 0);
+			draw_box(widget, field[i].pathsearch%9, field[i].pathsearch/9);
 		}
-	gtk_widget_draw(widget, NULL);
 }
 
 int
@@ -632,7 +646,7 @@ animate(gpointer gp)
 		{
 			set_inmove (0);
 		}
-		draw_box(widget, backpixmap, x, y, 1);
+		draw_box(widget, x, y);
 		x = newactive%9;
 		y = newactive/9;
 		field[newactive].phase = field[active].phase;
@@ -647,7 +661,7 @@ animate(gpointer gp)
 			active = -1;
 			field[newactive].phase = 0;
 			field[newactive].active = 0;
-			draw_ball(widget, backpixmap, x, y, field[newactive].color, field[newactive].phase, 1);
+			draw_ball(widget, x, y);
 			reset_pathsearch();
 			if(!check_goal(widget, newactive, 1))
 			{
@@ -669,7 +683,7 @@ animate(gpointer gp)
 
 	field[active].phase++;
 	if(field[active].phase >= 4) field[active].phase = 0;
-	draw_ball(widget, backpixmap, x, y, field[active].color, field[active].phase, 1);
+	draw_ball(widget, x, y);
 
 	return TRUE;
 }
@@ -701,6 +715,7 @@ static int
 game_about_callback (GtkWidget *widget, void *data)
 {
     GtkWidget *about;
+    GdkPixbuf *pixbuf = NULL;
     const gchar *authors[] = {
 		            _("Robert Szokovacs <szo@appaloosacorp.hu>"),
 			    _("Szabolcs Ban <shooby@gnome.hu>"),
@@ -711,16 +726,29 @@ game_about_callback (GtkWidget *widget, void *data)
                            NULL
                           };
    /* Translator credits */
-   gchar *translator_credits = _("");
+   gchar *translator_credits = _("translator_credits");
+
+   {
+	   char *filename = NULL;
+
+	   filename = gnome_program_locate_file (NULL,
+			   GNOME_FILE_DOMAIN_PIXMAP,  ("glines.png"),
+			   TRUE, NULL);
+	   if (filename != NULL)
+	   {
+		   pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		   g_free (filename);
+	   }
+   }
    					        
 	about = gnome_about_new (_("Glines"), VERSION,
 			_("(C) 1997-2000 the Free Software Foundation"),
 			_("Gnome port of the once-popular Color Lines game"),
 			(const char **)authors,
 			(const char **)documenters,
-                        (const char *)translator_credits,
-		        NULL);
-	gnome_dialog_set_parent(about), GTK_WINDOW(app);
+			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		        pixbuf);
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW(app));
 	gtk_widget_show (about);
 	return TRUE;
 }       
@@ -754,7 +782,6 @@ load_theme_cb(void)
   gnome_config_sync();
 
   load_theme();
-  draw_field(draw_area,1);
   draw_all_balls(draw_area, -1);
   draw_preview();
   glines_cancel(0,0);
@@ -1087,7 +1114,7 @@ GnomeUIInfo gamemenu[] = {
 
         GNOMEUIINFO_SEPARATOR,
 
-	GNOMEUIINFO_MENU_EXIT_ITEM(game_quit_callback, NULL),
+	GNOMEUIINFO_MENU_QUIT_ITEM(game_quit_callback, NULL),
 
 	GNOMEUIINFO_END
 };
@@ -1136,8 +1163,11 @@ main (int argc, char *argv [])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("glines", VERSION, LIBGNOMEUI_MODULE,
-			    argc, argv, GNOME_PARAM_POPT_TABLE, NULL, NULL);
+	gnome_program_init ("glines", VERSION,
+			      LIBGNOMEUI_MODULE,
+			      argc, argv,
+			      GNOME_PARAM_POPT_TABLE, NULL,
+			      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/glines.xpm");
 	client = gnome_master_client ();
 
@@ -1209,22 +1239,13 @@ main (int argc, char *argv [])
 
 	load_properties();
 
-	backpixmap = gdk_pixmap_new(draw_area->window,
-			BOXSIZE*FIELDSIZE,
-			BOXSIZE*FIELDSIZE,
-			-1);
-
-	next_backpixmap = gdk_pixmap_new(draw_area->window,
-			BOXSIZE*3,
-			BOXSIZE,
-			-1);
-
 	g_signal_connect (G_OBJECT(draw_area), "button_press_event",
-			  G_CALLBACK (button_press_event), NULL);                
+			  G_CALLBACK (button_press_event), NULL);
 	g_signal_connect (G_OBJECT (draw_area), "expose_event",
-			  G_CALLBACK (expose_event), backpixmap);
+			  G_CALLBACK (field_expose_event), NULL);
+
 	g_signal_connect (G_OBJECT (next_draw_area), "expose_event",
-			  G_CALLBACK (expose_event), next_backpixmap);
+			  G_CALLBACK (preview_expose_event), NULL);
 
 	gtk_widget_realize(next_draw_area);
 
