@@ -86,9 +86,8 @@ gchar *msg
 ){
   GtkWidget *box;
 
-  box = gnome_message_box_new(msg,
-			      GNOME_MESSAGE_BOX_INFO, 
-			      GNOME_STOCK_BUTTON_OK, NULL);
+  box = gnome_app_message (GNOME_APP(app),
+                           msg);
 
   gtk_window_set_modal(GTK_WINDOW(box), TRUE);
   gtk_widget_show(box);
@@ -146,10 +145,10 @@ gint sc
   guint pos;
   gchar sbuf[256];
 
-  if(properties_safe_moves()){
+  if(properties_super_safe_moves()){
+    sprintf(sbuf, "%s-super-safe", game_config_filename(current_game_config()));  } else
+if(properties_safe_moves()){
     sprintf(sbuf, "%s-safe", game_config_filename(current_game_config()));
-  } else if(properties_super_safe_moves()){
-    sprintf(sbuf, "%s-super-safe", game_config_filename(current_game_config()));
   } else {
     sprintf(sbuf, "%s", game_config_filename(current_game_config()));
   }
@@ -358,6 +357,10 @@ static void generate_level(
 
   safe_teleports += game_config()->free_safe_teleports;
 
+  if(safe_teleports > game_config()->max_safe_teleports){
+   safe_teleports = game_config()->max_safe_teleports;
+  }
+
   for(i = 0; i < num_robots1; ++i){
     while(1){
       xp = rand() % GAME_WIDTH;
@@ -625,7 +628,7 @@ void init_game(
 
   create_game_timer();
 
-  gtk_signal_connect(GTK_OBJECT(app), "key_press_event",
+  g_signal_connect(GTK_OBJECT(app), "key_press_event",
 		     GTK_SIGNAL_FUNC(keyboard_cb), 0);  
 }
 
