@@ -102,7 +102,7 @@ Tetris::Tetris(int cmdlLevel):
 	
 	GnomeUIInfo help_menu[] = 
 	{
-		GNOMEUIINFO_HELP((gpointer)"gnometris"),
+		/* FIXME GNOMEUIINFO_HELP((gpointer)"gnometris"), */
 		GNOMEUIINFO_MENU_ABOUT_ITEM(gameAbout, this),
 		GNOMEUIINFO_END
 	};
@@ -408,7 +408,7 @@ void
 Tetris::setRotateCounterClockWise(GtkWidget *widget, void *d)
 {
 	Tetris *t = (Tetris*) d;
-	gconf_client_set_bool (t->gconf_client, "/apps/gnometris/options/rotate_counter_click_wise", GTK_TOGGLE_BUTTON(widget)->active, NULL);
+	gconf_client_set_bool (t->gconf_client, "/apps/gnometris/options/rotate_counter_clock_wise", GTK_TOGGLE_BUTTON(widget)->active, NULL);
 }
 
 void
